@@ -1,5 +1,5 @@
 
-package Simplfy;
+package Net::Simplfy;
 
 =head1 NAME
  
@@ -104,7 +104,7 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.0.0
+1.0.1
 
 =head1 LICENSE
 
